==> jimubi-spring-boot-starter-1.9.4.jar: org/jeecg/modules/drag/sql/OnlDragPageDao_condition.sql <==
		<#if ( onlDragPage.id )?? && onlDragPage.id ?length gt 0>
		    /* 主键 */
			and odp.ID = :onlDragPage.id
		</#if>
		<#if ( onlDragPage.name )?? && onlDragPage.name ?length gt 0>
		    /* 界面名称 */
			and odp.NAME LIKE :onlDragPage.name
		</#if>
		<#if ( onlDragPage.style )?? && onlDragPage.style ?length gt 0>
		    /* 仪表盘风格 bigScreen:大屏 */
			and odp.STYLE = :onlDragPage.style
		</#if>
		<#if ( onlDragPage.izTemplate )?? && onlDragPage.izTemplate ?length gt 0>
		    /* 是否模板 */
			and odp.iz_template = :onlDragPage.izTemplate
		</#if>
		<#if ( onlDragPage.path )?? && onlDragPage.path ?length gt 0>
		    /* 访问路径 */
			and odp.PATH = :onlDragPage.path
		</#if>
		<#if ( onlDragPage.coverUrl )?? && onlDragPage.coverUrl ?length gt 0>
		    /* 封面图 */
			and odp.COVER_URL = :onlDragPage.coverUrl
		</#if>
		<#if ( onlDragPage.template )?? && onlDragPage.template ?length gt 0>
		    /* 布局json */
			and odp.TEMPLATE = :onlDragPage.template
		</#if>
		<#if ( onlDragPage.protectionCode )?? && onlDragPage.protectionCode ?length gt 0>
		    /* 保护码 */
			and odp.PROTECTION_CODE = :onlDragPage.protectionCode
		</#if>
		<#if ( onlDragPage.type )?? && onlDragPage.type ?length gt 0>
		    /* 分类(1:门户设计 2:仪表盘设计) */
			and odp.TYPE = :onlDragPage.type
		</#if>
        <#if ( onlDragPage.lowAppId )?? && onlDragPage.lowAppId ?length gt 0>
		    /* 应用ID */
			and odp.low_app_id = :onlDragPage.lowAppId
		</#if>
		<#if ( onlDragPage.tenantId )?? && onlDragPage.tenantId ?length gt 0>
		    /* 租户ID */
			and odp.tenant_id = :onlDragPage.tenantId
		</#if>
		<#if ( onlDragPage.createBy )?? && onlDragPage.createBy ?length gt 0>
		    /* 创建人登录名称 */
			and odp.CREATE_BY = :onlDragPage.createBy
		</#if>
	    <#if ( onlDragPage.createTime )??>
		    /* 创建日期 */
			and odp.CREATE_TIME = :onlDragPage.createTime
		</#if>
		<#if ( onlDragPage.updateBy )?? && onlDragPage.updateBy ?length gt 0>
		    /* 更新人登录名称 */
			and odp.UPDATE_BY = :onlDragPage.updateBy
		</#if>
	    <#if ( onlDragPage.updateTime )??>
		    /* 更新日期 */
			and odp.UPDATE_TIME = :onlDragPage.updateTime
		</#if>
	    <#if ( onlDragPage.delFlag ) ?exists>
		    /* 删除状态 */
			and odp.del_flag = :onlDragPage.delFlag
		</#if>

==> jimubi-spring-boot-starter-1.9.5.jar: org/jeecg/modules/drag/sql/OnlDragPageDao_condition.sql <==
		<#if ( onlDragPage.id )?? && onlDragPage.id ?length gt 0>
		    /* 主键 */
			and odp.ID = :onlDragPage.id
		</#if>
		<#if ( onlDragPage.name )?? && onlDragPage.name ?length gt 0>
		    /* 界面名称 */
			and odp.NAME LIKE :onlDragPage.name
		</#if>
		<#if ( onlDragPage.style )?? && onlDragPage.style ?length gt 0>
		    /* 仪表盘风格 bigScreen:大屏 */
			and odp.STYLE = :onlDragPage.style
		</#if>
		<#if ( onlDragPage.izTemplate )?? && onlDragPage.izTemplate ?length gt 0>
		    /* 是否模板 */
			and odp.iz_template = :onlDragPage.izTemplate
		</#if>
		<#if ( onlDragPage.path )?? && onlDragPage.path ?length gt 0>
		    /* 访问路径 */
			and odp.PATH = :onlDragPage.path
		</#if>
		<#if ( onlDragPage.coverUrl )?? && onlDragPage.coverUrl ?length gt 0>
		    /* 封面图 */
			and odp.COVER_URL = :onlDragPage.coverUrl
		</#if>
		<#if ( onlDragPage.template )?? && onlDragPage.template ?length gt 0>
		    /* 布局json */
			and odp.TEMPLATE = :onlDragPage.template
		</#if>
		<#if ( onlDragPage.protectionCode )?? && onlDragPage.protectionCode ?length gt 0>
		    /* 保护码 */
			and odp.PROTECTION_CODE = :onlDragPage.protectionCode
		</#if>
		<#if ( onlDragPage.type )?? && onlDragPage.type ?length gt 0>
		    /* 分类(1:门户设计 2:仪表盘设计) */
			and odp.TYPE = :onlDragPage.type
		</#if>
        <#if ( onlDragPage.lowAppId )?? && onlDragPage.lowAppId ?length gt 0>
		    /* 应用ID */
			and odp.low_app_id = :onlDragPage.lowAppId
		</#if>
		<#if ( onlDragPage.tenantId )?? && onlDragPage.tenantId ?length gt 0>
		    /* 租户ID */
			and odp.tenant_id = :onlDragPage.tenantId
		</#if>
		<#if ( onlDragPage.designType )?? && onlDragPage.designType ?length gt 0>
		    /* 仪表盘设计类型 */
			and odp.design_type= :onlDragPage.designType
		</#if>
		<#if ( onlDragPage.createBy )?? && onlDragPage.createBy ?length gt 0>
		    /* 创建人登录名称 */
			and odp.CREATE_BY = :onlDragPage.createBy
		</#if>
	    <#if ( onlDragPage.createTime )??>
		    /* 创建日期 */
			and odp.CREATE_TIME = :onlDragPage.createTime
		</#if>
		<#if ( onlDragPage.updateBy )?? && onlDragPage.updateBy ?length gt 0>
		    /* 更新人登录名称 */
			and odp.UPDATE_BY = :onlDragPage.updateBy
		</#if>
	    <#if ( onlDragPage.updateTime )??>
		    /* 更新日期 */
			and odp.UPDATE_TIME = :onlDragPage.updateTime
		</#if>
	    <#if ( onlDragPage.delFlag ) ?exists>
		    /* 删除状态 */
			and odp.del_flag = :onlDragPage.delFlag
		</#if>
